@@ -1,6 +1,4 @@
-"""
-Currency definitions that are based on the [ISO4217](https://en.wikipedia.org/wiki/ISO_4217).
-"""
+"""Currency definitions that are based on the [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)."""
 
 from __future__ import annotations
 
@@ -11,11 +9,11 @@ from pydantic_core import PydanticCustomError, core_schema
 
 try:
     import pycountry
-except ModuleNotFoundError:  # pragma: no cover
+except ModuleNotFoundError as e:  # pragma: no cover
     raise RuntimeError(
         'The `currency_code` module requires "pycountry" to be installed. You can install it with "pip install '
         'pycountry".'
-    )
+    ) from e
 
 # List of codes that should not be usually used within regular transactions
 _CODES_FOR_BONDS_METAL_TESTING = {
@@ -41,9 +39,11 @@ class ISO4217(str):
 
     from pydantic_extra_types.currency_code import ISO4217
 
+
     class Currency(BaseModel):
         alpha_3: ISO4217
 
+
     currency = Currency(alpha_3='AED')
     print(currency)
     # > alpha_3='AED'
@@ -55,8 +55,7 @@ class ISO4217(str):
 
     @classmethod
     def _validate(cls, currency_code: str, _: core_schema.ValidationInfo) -> str:
-        """
-        Validate a ISO 4217 language code from the provided str value.
+        """Validate a ISO 4217 language code from the provided str value.
 
         Args:
             currency_code: The str value to be validated.
@@ -68,6 +67,7 @@ class ISO4217(str):
         Raises:
             PydanticCustomError: If the ISO 4217 currency code is not valid.
         """
+        currency_code = currency_code.upper()
         if currency_code not in cls.allowed_currencies:
             raise PydanticCustomError(
                 'ISO4217', 'Invalid ISO 4217 currency code. See https://en.wikipedia.org/wiki/ISO_4217'
@@ -98,9 +98,11 @@ class Currency(str):
 
         from pydantic_extra_types.currency_code import Currency
 
+
         class currency(BaseModel):
             alpha_3: Currency
 
+
         cur = currency(alpha_3='AED')
         print(cur)
         # > alpha_3='AED'
@@ -114,8 +116,7 @@ class Currency(str):
 
     @classmethod
     def _validate(cls, currency_symbol: str, _: core_schema.ValidationInfo) -> str:
-        """
-        Validate a subset of the [ISO4217](https://en.wikipedia.org/wiki/ISO_4217) format.
+        """Validate a subset of the [ISO4217](https://en.wikipedia.org/wiki/ISO_4217) format.
         It excludes bonds testing codes and precious metals.
 
         Args:
@@ -128,27 +129,27 @@ class Currency(str):
         Raises:
             PydanticCustomError: If the ISO 4217 currency code is not valid or is bond, precious metal or testing code.
         """
+        currency_symbol = currency_symbol.upper()
         if currency_symbol not in cls.allowed_currencies:
             raise PydanticCustomError(
                 'InvalidCurrency',
                 'Invalid currency code.'
-                ' See https://en.wikipedia.org/wiki/ISO_4217. '
+                ' See https://en.wikipedia.org/wiki/ISO_4217 . '
                 'Bonds, testing and precious metals codes are not allowed.',
             )
         return currency_symbol
 
     @classmethod
     def __get_pydantic_core_schema__(cls, _: type[Any], __: GetCoreSchemaHandler) -> core_schema.CoreSchema:
-        """
-        Return a Pydantic CoreSchema with the currency subset of the
+        """Return a Pydantic CoreSchema with the currency subset of the
         [ISO4217](https://en.wikipedia.org/wiki/ISO_4217) format.
         It excludes bonds testing codes and precious metals.
 
-         Args:
+        Args:
              _: The source type.
              __: The handler to get the CoreSchema.
 
-         Returns:
+        Returns:
             A Pydantic CoreSchema with the subset of the currency subset of the
             [ISO4217](https://en.wikipedia.org/wiki/ISO_4217) format.
             It excludes bonds testing codes and precious metals.
@@ -162,8 +163,7 @@ class Currency(str):
     def __get_pydantic_json_schema__(
         cls, schema: core_schema.CoreSchema, handler: GetJsonSchemaHandler
     ) -> dict[str, Any]:
-        """
-        Return a Pydantic JSON Schema with subset of the [ISO4217](https://en.wikipedia.org/wiki/ISO_4217) format.
+        """Return a Pydantic JSON Schema with subset of the [ISO4217](https://en.wikipedia.org/wiki/ISO_4217) format.
         Excluding bonds testing codes and precious metals.
 
         Args:
